@@ -5,12 +5,12 @@ use Role::Tiny;
 use Carp 'croak';
 use File::Basename ();
 use File::Spec;
-use Mojo::Util qw(encode monkey_patch);
+use Mojo::Util 'encode';
 use Selenium::Remote::WDKeys ();
 
 use constant DEBUG => $ENV{MOJO_SELENIUM_DEBUG} || 0;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 my $SCRIPT_NAME = File::Basename::basename($0);
 my $SCREENSHOT  = 1;
@@ -114,6 +114,18 @@ sub element_is_hidden {
 sub go_back    { $_[0]->_proxy('go_back');    $_[0] }
 sub go_forward { $_[0]->_proxy('go_forward'); $_[0] }
 
+sub if_tx {
+  my ($self, $method) = (shift, shift);
+
+SKIP: {
+    my $desc = ref $method ? '__SUB__' : $method;
+    Test::More::skip("\$t->tx() is not defined ($desc)", 1) unless $self->tx;
+    $self->$method(@_);
+  }
+
+  return $self;
+}
+
 sub live_element_count_is {
   my ($self, $selector, $count, $desc) = @_;
   my $els = $self->_proxy(find_elements => $selector);
@@ -189,7 +201,9 @@ sub navigate_ok {
 around new => sub {
   my $next = shift;
   my $self = $next->(@_);
+  my $app  = $self->app;
   $self->ua(Test::Mojo::Role::Selenium::UserAgent->new->ioloop(Mojo::IOLoop->singleton));
+  $self->app($app) if $app;
   return $self;
 };
 
@@ -228,6 +242,18 @@ sub set_window_size {
   return $self;
 }
 
+sub skip_all_or_setup {
+  my $self = shift;
+
+  local $@;
+  Test::More::plan(skip_all => $@ || 'TEST_SELENIUM=1 or TEST_SELENIUM=http://...')
+    unless $ENV{TEST_SELENIUM} and eval { $self->driver };
+
+  $ENV{MOJO_SELENIUM_BASE_URL} //= $ENV{TEST_SELENIUM} if $ENV{TEST_SELENIUM} =~ /^http/;
+
+  return $self;
+}
+
 sub submit_ok {
   my ($self, $selector, $desc) = @_;
   my $el = $self->_proxy(find_element => $selector);
@@ -325,13 +351,9 @@ Test::Mojo::Role::Selenium - Test::Mojo in a real browser
   use Test::Mojo::WithRoles "Selenium";
   use Test::More;
 
-  my $t = Test::Mojo::WithRoles->new;
-
-  $ENV{MOJO_SELENIUM_BASE_URL} = $ENV{TEST_BASE_URL} || '';
   $ENV{MOJO_SELENIUM_DRIVER} ||= 'Selenium::Chrome';
 
-  plan skip_all => $@ || 'TEST_BASE_URL=http://mojolicious.org'
-    unless $ENV{TEST_BASE_URL} and eval { $t->driver };
+  my $t = Test::Mojo::WithRoles->new->skip_all_or_setup;
 
   $t->navigate_ok('/perldoc')
     ->live_text_is('a[href="#GUIDES"]' => 'GUIDES');
@@ -351,15 +373,12 @@ Test::Mojo::Role::Selenium - Test::Mojo in a real browser
   use Test::Mojo::WithRoles "Selenium";
   use Test::More;
 
-  my $t = Test::Mojo::WithRoles->new("MyApp");
+  my $t = Test::Mojo::WithRoles->new("MyApp")->skip_all_or_setup;
 
   # All the standard Test::Mojo methods are available
   ok $t->isa("Test::Mojo");
   ok $t->does("Test::Mojo::Role::Selenium");
 
-  # Make sure the selenium driver can be initialized
-  plan skip_all => $@ unless eval { $t->driver };
-
   $t->navigate_ok("/")
     ->status_is(200)
     ->header_is("Server" => "Mojolicious (Perl)")
@@ -402,24 +421,24 @@ are a quick intro to install some of the dependencies to make this module work.
 
 =item * L<Selenium::Chrome>
 
-  # osx
+  # macOS
   $ brew install chromedriver
 
-  # ubuntu
+  # Ubuntu
   $ sudo apt-get install chromium-chromedriver
 
-  # run tests
+  # Run tests
   $ MOJO_SELENIUM_DRIVER=Selenium::Chrome prove -l
 
 =item * L<Selenium::PhantomJS>
 
-  # osx
+  # macOS
   $ brew install phantomjs
 
-  # ubuntu
+  # Ubuntu
   $ sudo apt-get install phantomjs
 
-  # run tests
+  # Run tests
   $ MOJO_SELENIUM_DRIVER=Selenium::PhantomJS prove -l
 
 =back
@@ -547,6 +566,18 @@ Equivalent to hitting the forward button on the browser.
 
 See L<Selenium::Remote::Driver/go_forward>.
 
+=head2 if_tx
+
+  $self = $self->if_tx(sub { ... }, @args);
+  $self = $self->if_tx($method, @args);
+
+Call either a code ref or a method on C<$self> if L<Test::Mojo/tx> is defined.
+C<tx()> is undefined if L</navigate_ok> is called on an external resource.
+
+Examples:
+
+  $self->if_tx(status_is => 200);
+
 =head2 live_element_count_is
 
   $self = $self->live_element_count_is("a", 12);
@@ -621,7 +652,7 @@ See L<Selenium::Remote::Driver/refresh>.
   $self->send_keys_ok("input[name=username]", "jhthorsen");
   $self->send_keys_ok("input[name=name]", ["jan", \"space", "henning"]);
 
-Used to sen keys to a given element. Scalar refs will be sent as
+Used to send keys to a given element. Scalar refs will be sent as
 L<Selenium::Remote::WDKeys> strings.
 
 List of some of the special keys:
@@ -647,6 +678,15 @@ List of some of the special keys:
 
 Set the browser window size.
 
+=head2 skip_all_or_setup
+
+  $self = $self->skip_all_or_setup;
+
+Will L<skip all#Test::More/skip_all> tests unless C<TEST_SELENIUM> is set and
+and L</driver> can be built.
+
+Will also set L</MOJO_SELENIUM_BASE_URL> if C<TEST_SELENIUM> looks like a URL.
+
 =head2 submit_ok
 
   $self = $self->submit_ok("form");
